==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/fr.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: fr.php,v 1.19 2005/12/07 15:02:11 bigmichi1 Exp $

$text['title']          = 'Informations Systme ';

$text['vitals']         = 'Systme';
$text['hostname']       = 'Nom d\'hte cannonique';
$text['ip']             = 'IP';
$text['kversion']       = 'Version du noyau';
$text['dversion']       = 'Distribution';
$text['uptime']         = 'Uptime';
$text['users']          = 'Utilisateurs';
$text['loadavg']        = 'Charge systme';

$text['hardware']       = 'Informations Matriel';
$text['numcpu']         = 'Processeurs';
$text['cpumodel']       = 'Modle';
$text['mhz']            = 'Frquence';
$text['cache']          = 'Taille Cache';
$text['bogomips']       = 'Bogomips';
$text['usb']            = 'Priph. USB';
$text['pci']            = 'Priph. PCI';
$text['ide']            = 'Priph. IDE';
$text['scsi']           = 'Priph. SCSI';

$text['netusage']       = 'Rseau';
$text['device']         = 'Priphrique';
$text['received']       = 'Rception';
$text['sent']           = 'Envoi';
$text['errors']         = 'Err/Drop';

$text['memusage']       = 'Utilisation mmoire';
$text['phymem']         = 'Mmoire Physique';
$text['swap']           = 'Swap disque';

$text['fs']             = 'Systmes de fichiers monts';
$text['mount']          = 'Point';
$text['partition']      = 'Partition';

$text['percent']        = 'Utilisation';
$text['type']           = 'Type';
$text['free']           = 'Libre';
$text['used']           = 'Occup';
$text['size']           = 'Taille';
$text['totals']         = 'Totaux';

$text['kb']             = 'Ko';
$text['mb']             = 'Mo';
$text['gb']             = 'Go';

$text['none']           = 'aucun';

$text['capacity']       = 'Capacit';
  
$text['template']       = 'Modle ';
$text['language']       = 'Langue ';
$text['submit']         = 'Valider';
$text['created']        = 'Cr par';
$text['locale']         = 'fr_FR';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'jours';
$text['hours']          = 'heures';
$text['minutes']        = 'minutes';

$text['temperature']    = 'Temprature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Ventilateurs';
$text['s_value']        = 'valeur';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hystrsis';
$text['s_limit']        = 'Limite';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/fr.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: fr.php,v 1.24 2006/06/05 11:48:16 bigmichi1 Exp $

$text['title']          = 'Informations Syst&egrave;me ';

$text['vitals']         = 'Syst&egrave;me';
$text['hostname']       = 'Nom d\'h&ocirc;te cannonique';
$text['ip']             = 'IP';
$text['kversion']       = 'Version du noyau';
$text['dversion']       = 'Distribution';
$text['uptime']         = 'Uptime';
$text['users']          = 'Utilisateurs';
$text['loadavg']        = 'Charge syst&egrave;me';

$text['hardware']       = 'Informations Mat&eacute;riel';
$text['numcpu']         = 'Processeurs';
$text['cpumodel']       = 'Mod&egrave;le';
$text['cpuspeed']	= 'Vitesse CPU';
$text['busspeed']	= 'Vitesse BUS';
$text['cache']          = 'Taille Cache';
$text['bogomips']       = 'Bogomips';
$text['usb']            = 'P&eacute;riph. USB';
$text['pci']            = 'P&eacute;riph. PCI';
$text['ide']            = 'P&eacute;riph. IDE';
$text['scsi']           = 'P&eacute;riph. SCSI';

$text['netusage']       = 'R&eacute;seau';
$text['device']         = 'P&eacute;riph&eacute;rique';
$text['received']       = 'R&eacute;ception';
$text['sent']           = 'Envoi';
$text['errors']         = 'Err/Drop';

$text['memusage']       = 'Utilisation m&eacute;moire';
$text['phymem']         = 'M&eacute;moire Physique';
$text['swap']           = 'Swap disque';

$text['fs']             = 'Syst&egrave;mes de fichiers mont&eacute;s';
$text['mount']          = 'Point';
$text['partition']      = 'Partition';

$text['percent']        = 'Utilisation';
$text['type']           = 'Type';
$text['free']           = 'Libre';
$text['used']           = 'Occup&eacute;';
$text['size']           = 'Taille';
$text['totals']         = 'Totaux';

$text['kb']             = 'Ko';
$text['mb']             = 'Mo';
$text['gb']             = 'Go';

$text['none']           = 'aucun';

$text['capacity']       = 'Capacit&eacute;';
  
$text['template']       = 'Mod&egrave;le ';
$text['language']       = 'Langue ';
$text['submit']         = 'Valider';
$text['created']        = 'Cr&eacute;&eacute; par';
$text['locale']         = 'fr_FR';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'jours';
$text['hours']          = 'heures';
$text['minutes']        = 'minutes';

$text['temperature']    = 'Temp&eacute;rature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Ventilateurs';
$text['s_value']        = 'valeur';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hyst&eacute;r&eacute;sis';
$text['s_limit']        = 'Limite';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
